# This is the folder name within each installed app in which we look for (and save) migration files
MIGRATIONS_FOLDER = "massmigrations"

DEFAULT_BACKEND = "massmigration.backends.djangae.DjangaeBackend"
